package com.qmth.cqb.paper.web;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

import com.qmth.cqb.paper.dao.PaperRepo;
import com.qmth.cqb.paper.service.ImportPaperService;
import com.qmth.cqb.paper.service.PaperService;

import io.swagger.annotations.ApiOperation;

/**
 * Created by songyue on 16/12/28.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class ImportPaperController {

    @Autowired
    ImportPaperService importPaperService;

    @Autowired
    PaperRepo paperRepo;

    @Autowired
    PaperService paperService;

    /**
     * 导入试卷
     * 
     * @param paperName
     * @param file
     * @return
     */
    @ApiOperation(value = "导入试卷", notes = "导入试卷")
    @PostMapping(value = "/importPaper")
    public ResponseEntity importPaper(@RequestParam String paperName, @RequestParam String courseNo,
            @RequestParam("file") CommonsMultipartFile file) {
        File tempFile = importPaperService.getUploadFile(file);
        String returnStr = importPaperService.ImportPaper(paperName, courseNo, tempFile);
        if (returnStr.equals("success")) {
            return new ResponseEntity(returnStr, HttpStatus.OK);
        } else {
            Map map = new HashMap();
            map.put("errorMsg", returnStr);
            return new ResponseEntity(map, HttpStatus.INTERNAL_SERVER_ERROR);
        }
        // return returnStr;
    }

    /**
     * 新增一张空白试卷
     * 
     * @param paper
     * @return
     */
    @ApiOperation(value = "保存导入类型空白试卷", notes = "保存导入类型空白试卷")
    @PostMapping(value = "/importPaper/saveBlankPaper/{courseNo}/{paperName}")
    public ResponseEntity saveBlankPaper(@PathVariable String courseNo, @PathVariable String paperName) {
        String msg = importPaperService.saveBlankPaper(courseNo, paperName);
        if (msg.equals("success")) {
            return new ResponseEntity(msg, HttpStatus.OK);
        } else {
            return new ResponseEntity(msg, HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }

}
